@@ -5,9 +5,10 @@ from .env import Env
 from .auth.keycloak import Keycloak
 
 
-def load_configs(role):
+def load_configs(app_role):
     env = Env()
 
+    app_role = env("CONFIGS_ROLE_NAME", default=app_role)
     configs_protocol = env("CONFIGS_PROTOCOL", default="https")
     configs_host = env("CONFIGS_HOST", default="configs.avd.al")
     configs_client = env("CONFIGS_CLIENT_ID", default="")
@@ -38,10 +39,11 @@ def load_configs(role):
             return
 
         for k, v in res.json().items():
-            os.environ[k] = str(v)
+            if k not in os.environ:
+                os.environ[k] = str(v)
         
         print(f"loaded role: {role}")
 
-    load_role(role)
+    load_role(app_role)
     load_role("common")
     load_role(socket.gethostname().lower())
